==> lack-1.0.tar.gz: lack-1.0/needs.ml <==
(**************************************************************************)
(*  Lack - Package manager for non-root users                             *)
(*  (C) 2008 Olivier Schwander <olivier.schwander@ens-lyon.org>           *)
(*  http://chadok.info/lack                                               *)
(*                                                                        *)
(*  This file is part of Lack.                                            *)
(*                                                                        *)
(*  Lack is free software: you can redistribute it and/or modify          *)
(*  it under the terms of the GNU General Public License as published by  *)
(*  the Free Software Foundation, either version 3 of the License, or     *)
(*  (at your option) any later version.                                   *)
(*                                                                        *)
(*  Foobar is distributed in the hope that it will be useful,             *)
(*  but WITHOUT ANY WARRANTY; without even the implied warranty of        *)
(*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *)
(*  GNU General Public License for more details.                          *)
(*                                                                        *)
(*  You should have received a copy of the GNU General Public License     *)
(*  along with Foobar.  If not, see <http://www.gnu.org/licenses/>.       *)
(*                                                                        *)
(**************************************************************************)

open Package
open Utils

exception Unknown_test

let test verbose base p =
  let (test, kind) = p.pkg_test in
    match kind with
      | "exec" -> command verbose test
      | _ -> raise Unknown_test

==> lack-1.1.tar.gz: lack-1.1/needs.ml <==
(**************************************************************************)
(*  Lack - Package manager for non-root users                             *)
(*  (C) 2008 Olivier Schwander <olivier.schwander@ens-lyon.org>           *)
(*  http://chadok.info/lack                                               *)
(*                                                                        *)
(*  This file is part of Lack.                                            *)
(*                                                                        *)
(*  Lack is free software: you can redistribute it and/or modify          *)
(*  it under the terms of the GNU General Public License as published by  *)
(*  the Free Software Foundation, either version 3 of the License, or     *)
(*  (at your option) any later version.                                   *)
(*                                                                        *)
(*  Lack is distributed in the hope that it will be useful,             *)
(*  but WITHOUT ANY WARRANTY; without even the implied warranty of        *)
(*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *)
(*  GNU General Public License for more details.                          *)
(*                                                                        *)
(*  You should have received a copy of the GNU General Public License     *)
(*  along with Lack.  If not, see <http://www.gnu.org/licenses/>.       *)
(*                                                                        *)
(**************************************************************************)

open Package
open Utils

exception Unknown_test

let test verbose base p =
  let (test, kind) = p.pkg_test in
    match kind with
      | "exec" -> command verbose test
      | _ -> raise Unknown_test
